;This procedure is intended for use as part of the PMIAS system.  This system
;has been developed by the HAO dPMon project to facilitate the initial
;quality assurance procedures required for new dPMon data.  Please make
;no changes to any of the files in this directory without first contacting
;dPMon personnel.
;
;   Questions regarding PMIAS should be directed to:
;
;			Ray Wrigley     FL2 3084  x1588
;			Alice Lecinski  FL2 3037  x1523
;
;   This module oversees the arrangement of the log file entries to
;   form the final output to be written to the log files.
;
pro pmias_logenter, comm_in
@pmias_common

if comms_done ne 1 then begin	;First section for image comment input.

   if arch_in eq 1 then goto, ARCHIN

   case cur_typ of
      'LIMB' : begin
		  lm_comments(cntr) = comm_in
		  lm_done(cntr) = 1
		  lm_qual(cntr) = cur_qual
		  cur_done = lm_done
	       end
      'DISK' : begin
		  ds_comments(cntr) = comm_in
		  ds_done(cntr) = 1
		  ds_qual(cntr) = cur_qual
		  cur_done = ds_done
	       end
      'SKY' : begin
		 sk_comments(cntr) = comm_in
		 sk_done(cntr) = 1
		 sk_qual(cntr) = cur_qual
		 cur_done = sk_done
	      end
      'DIFFUSER' : begin
		      ff_comments(cntr) = comm_in
		      ff_done(cntr) = 1
		      ff_qual(cntr) = cur_qual
		      cur_done = ff_done
		   end
      'LIMB DARK' : begin
		       lmd_comments(cntr) = comm_in
		       lmd_done(cntr) = 1
		       lmd_qual(cntr) = cur_qual
		       cur_done = lmd_done
		    end
      'DISK DARK' : begin
		       dsd_comments(cntr) = comm_in
		       dsd_done(cntr) = 1
		       dsd_qual(cntr) = cur_qual
		       cur_done = dsd_done
		    end
      'SKY DARK' : begin
		      skd_comments(cntr) = comm_in
		      skd_done(cntr) = 1
		      skd_qual(cntr) = cur_qual
		      cur_done = skd_done
		   end
      'DIFF DARK' : begin
		       ffd_comments(cntr) = comm_in
		       ffd_done(cntr) = 1
		       ffd_qual(cntr) = cur_qual
		       cur_done = ffd_done
		    end
   endcase

   cur_qual = ' none'		;Reset quality selection string for next one.

   next_intyp = min(where(cur_done eq 0))	;Check to see if all comments
					;are in for the current image type.
   if next_intyp ne -1 then begin
      widget_control, nxlog, set_value = string(next_intyp)
      pmias_imchange, 'NXLOG'
      widget_control, usr_out2, set_value = ' '
      widget_control, usr_in1, set_value = ' '
   endif else begin
      widget_control, nxlog, set_value = ' '
      if cur_typ ne 'LIMB' and cur_typ ne 'DISK' then begin
	 widget_control, usr_out1, set_value = 'Done with this type.'
	 case cur_typ of
	    'SKY' : log_done(2) = 1
	    'DIFFUSER' : log_done(3) = 1
	    'LIMB DARK' : log_done(4) = 1
	    'DISK DARK' : log_done(5) = 1
	    'SKY DARK' : log_done(6) = 1
	    'DIFF DARK' : log_done(7) = 1
	 endcase
       endif else begin
	  widget_control, col2bab, sensitive = 1
	  widget_control, usr_out1, set_value = $
	  'Select archive image for '+cur_typ+' images, then press ARCHIVE.'
       endelse
   endelse

   ARCHIN:   ;Jump to here if archive image is being selected.

   if arch_in eq 1 then begin
      widget_control, usr_out1, set_value =$
      'Archive image selected.  Select another image type and continue.'
      widget_control, usr_out2, set_value = 'ARCH'
      widget_control, col2bab, sensitive = 0
   endif
   arch_in = 0 				;Reset arch. select indicator.
   more = where(log_done eq 0)		;Check to see if comments are done
   if more(0) eq -1 then comms_done = 1	;for ALL image types.  If so, proceed
endif					;with summaries.

if comms_done eq 1 and summs_done eq 0 then begin     ;Entry of each summary.
   widget_control, usr_in1, set_value = ''
   widget_control, col2bac, sensitive = 1
   widget_control, usr_out1, set_value = $
   'Enter summaries.  When done with each, press appropriate ENTER button.'
   cur_summ = [cur_summ, comm_in]
   widget_control, usr_in1, set_value = ' '
endif

if summs_done eq 1 then begin
   widget_control, usr_out1, set_value =$
   'Daily log file being written,  archive images being stored.'
   pmias_writelogs
   widget_control, usr_out2, set_value = ' '
   widget_control, usr_out1, set_value =$
   'Logs files have been written.  You are free to look at images or exit.'
   widget_control, col2b, sensitive = 0
endif

return
end
