;This procedure is intended for use as part of the PMIAS system.  This system
;has been developed by the HAO dPMon project to facilitate the initial
;quality assurance procedures required for new dPMon data.  Please make
;no changes to any of the files in this directory without first contacting
;dPMon personnel.
;
;   Questions regarding PMIAS should be directed to:
;
;			Ray Wrigley     FL2 3084  x1588
;			Alice Lecinski  FL2 3037  x1523
;
;   When all the information for the logfile is in, control is handed to
;   this routine, which then organizes the various string arrays and 
;   writes the actual log file, storing it the predetermined directory.
;   Also, this routine writes the archived limb and disk data files to
;   their appropriate storage locations.
;
pro pmias_writelogs
@pmias_common

;Set up arrays to hold lines of log file related to individual images.
limb_strs = strarr(n_elements(limb_fnms))
disk_strs = strarr(n_elements(disk_fnms))
sky_strs = strarr(n_elements(sky_fnms))
flat_strs = strarr(n_elements(flat_fnms))
limbd_strs = strarr(n_elements(limbd_fnms))
diskd_strs = strarr(n_elements(diskd_fnms))
skyd_strs = strarr(n_elements(skyd_fnms))
flatd_strs = strarr(n_elements(flatd_fnms))

;Create filename/comment lines of logfile.
for a = 0, n_elements(limb_fnms) - 1 do begin
   limb_strs(a) = limb_fnms(a) + lm_qual(a) + lm_comments(a)
endfor

for a = 0, n_elements(disk_fnms) - 1 do begin
   disk_strs(a) = disk_fnms(a) + ds_qual(a) + ds_comments(a)
endfor

for a = 0, n_elements(sky_fnms) - 1 do begin
   sky_strs(a) = sky_fnms(a) + sk_qual(a) + sk_comments(a)
endfor

for a = 0, n_elements(flat_fnms) - 1 do begin
   flat_strs(a) = flat_fnms(a) + ff_qual(a) + ff_comments(a)
endfor

for a = 0, n_elements(limbd_fnms) - 1 do begin
   limbd_strs(a) = limbd_fnms(a) + lmd_qual(a) + lmd_comments(a)
endfor

for a = 0, n_elements(diskd_fnms) - 1 do begin
   diskd_strs(a) = diskd_fnms(a) + dsd_qual(a) + dsd_comments(a)
endfor

for a = 0, n_elements(skyd_fnms) - 1 do begin
   skyd_strs(a) = skyd_fnms(a) + skd_qual(a) + skd_comments(a)
endfor

for a = 0, n_elements(flatd_fnms) - 1 do begin
   flatd_strs(a) = flatd_fnms(a) + ffd_qual(a) + ffd_comments(a)
endfor

fnm_comm_array = [limb_strs, ' ', disk_strs, ' ', sky_strs, ' ', flat_strs,$ 
	   ' ', limbd_strs, ' ',diskd_strs, ' ', skyd_strs, ' ', flatd_strs]

;Yank out any n's which are artifacts of the absence of a file type.
if (where(strtrim(fnm_comm_array, 2) eq 'n'))(0) ne -1 then begin
   fnm_comm_array = fnm_comm_array(where(strtrim(fnm_comm_array, 2) ne 'n'))
endif

;Get the year of the image file and create the string for the path to save to.
endyr = strmid(dataday, 0, 2)
if fix(endyr) gt 78 then yr = '19' + endyr else yr = '20' + endyr
path = '/jabba/ftp/dpm/log/' + yr

;Begin writing to output file.
get_lun, lun

tpfile = path + '/tmp.log'
lgfile = path + '/' + dataday + '.log'

openw,  lun, tpfile

printf, lun, transpose(fnm_comm_array)
printf, lun, ' '
printf, lun, 'Start time: ' + start_time
printf, lun, 'Stop time : ' + stop_time
printf, lun, ' '
printf, lun, 'Daily Summary : '
printf, lun, daily_summ
printf, lun, ' '
printf, lun, 'Limb Events : '
printf, lun, limb_events
printf, lun, ' '
printf, lun, 'Disk Events : '
printf, lun, disk_events
printf, lun, ' '
cur_time_str = strmid(!stime, 0, 12)
printf, lun, 'These notes recorded by ' + op_name + ', ' + cur_time_str
close, lun

cmnd='cat '+tpfile+' >> '+lgfile
spawn,cmnd
cmnd='/bin/rm '+tpfile
spawn,cmnd

;Make second copy of logfile in /slug/d/cordyn/DATA_BASE/pmiasLogs
cp_str = 'cp ' + path + '/' + dataday + '.log'+' /slug/d/cordyn/DATA_BASE/pmiasLogs/'+$
	dataday + '.log'
spawn, cp_str

;Generate month name from day of year, for use below.
year = fix(yr)
day = fix(strmid(dataday, 3, 3))

mons=['01_jan','02_feb','03_mar','04_apr','05_may','06_jun','07_jul','08_aug','09_sep','10_oct','11_nov','12_dec']

mon_dys = [[0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334],$
	   [0, 31, 60, 91, 121, 152, 182, 213, 244, 274, 305, 335]]

leap = ((year mod 4 eq 0) and (year mod 100 ne 0)) or (year mod 400 eq 0)

ix = where(day gt mon_dys(*, leap))
month = mons(max(ix))

;;; Copy archive image files to final daily_images directory.
;;; These will make the composites.
cp_cmd_lm = 'cp ' + topdir + dataday + '/' + lm_arch_fnm  +$
      ' /jabba/ftp/dpm/daily_images/' + yr + '/' + month

cp_cmd_ds = 'cp ' + topdir + dataday + '/' + ds_arch_fnm  +$
      ' /jabba/ftp/dpm/daily_images/' + yr + '/' + month


print,'Trying to copy limb archive image.' & spawn, cp_cmd_lm
print,'Trying to copy disk archive image.' & spawn, cp_cmd_ds

;;; Copy the a bias and gain and disk image to the 'band' directory.
;;; These will make the Flattened images.
;;; Get the minutes from the "ds_arch_fnm"

    ;;96d107.190046.d.fits
    ;;0123456789.12

if(oldheader eq 1 ) then begin ;{
    ;; 95d023.190202.d.fits
    spt=0
endif else begin ;}{
    ;; mlso_dpmn_alr_96d151_172741.fts
    spt=14
endelse ;}

    yrddoy=(strmid(ds_arch_fnm, spt+0, 7))
    hrs=fix(strmid(ds_arch_fnm, spt+7, 2))
    mns=fix(strmid(ds_arch_fnm, spt+9, 2))
    if ( mns gt 30 ) then hrs = hrs + 1
    hrss = strcompress(string(hrs),/remove_all)

    bdisk  = topdir + dataday + '/' +ds_arch_fnm
    if(oldheader eq 1 ) then begin ;{
	flatf  = topdir + dataday + '/' +yrddoy+hrss+'*.f.fits'
	limbdf = topdir + dataday + '/' +yrddoy+hrss+'*.ld.fits'
    endif else begin ;}{ 
	flatf  = topdir + dataday + '/' +'*adr_'+yrddoy+hrss+'*.fts'
	limbdf = topdir + dataday + '/' +'*xbr_'+yrddoy+hrss+'*.fts'
    endelse ;}

    cp_cmd = 'cp '+bdisk+' '+flatf+' '+limbdf+' /jabba/ftp/dpm/FlatPro'
    spawn,cp_cmd




return
end
