;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; This procedure will draw a grid over the current image.
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

pro pmias_draw_grid, image  ;;;, image

@pmias_common

DONE = 0  ;;;;;;;; Variable used for controlling the while loop...

D_VAL = 300     ;;;;;  This value is used to determine the "edge" of the disk..

TRUE = 1  & FALSE = 0     ;;;;;;;;; BOOLEAN VALUES

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Must get a handle on the current image...
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

grid_image = big_im

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Using the current image, the solar center will be "determined" 
;; (there is margin for error here!!!!)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

_x_temp = 764 &  _y_temp = 514 ;;;;;;;Center of image,(start in the middle)

ledge = _x_temp & WHILE(grid_image(ledge,_y_temp) GT D_VAL) $
		DO ledge=ledge-1
redge = _x_temp & WHILE(grid_image(redge,_y_temp) GT D_VAL) $
		DO redge=redge+1
top   = _y_temp & WHILE(grid_image(_x_temp, top) GT D_VAL) $
		DO top=top+1
bottom = _y_temp & WHILE(grid_image(_x_temp, bottom) GT D_VAL) $
		DO bottom=bottom-1
ledge=ledge+1
redge=redge-1
top=top-1
bottom=bottom+1

XDIAM = redge - ledge
YDIAM = top - bottom

SOL_CEN_X = ( (redge - fix(XDIAM/2)) + (ledge + fix(XDIAM/2)) )/2 
SOL_CEN_Y = ( (bottom + fix(YDIAM/2)) + (top - fix(YDIAM/2)) )/2

LEV=grid_image(ledge,SOL_CEN_Y) & REV=grid_image(redge,SOL_CEN_Y)
TEV=grid_image(SOL_CEN_X,top)   & BEV=grid_image(SOL_CEN_X,bottom)

cen_x = SOL_CEN_X & cen_y = SOL_CEN_Y
X_RAD = 0 & Y_RAD = 0

while(grid_image(cen_x, cen_y) GT D_VAL) do begin
    X_RAD = X_RAD + 1
    cen_x = cen_x + 1
endwhile
cen_x = SOL_CEN_X
while(grid_image(cen_x, cen_y) GT D_VAL) do begin
    Y_RAD = Y_RAD + 1
    cen_y = cen_y - 1
endwhile

 X_RAD = X_RAD - 1 & Y_RAD = Y_RAD - 1 ;; Subtract one to compensate for over counting above

if (X_RAD EQ Y_RAD) then SOL_RAD = X_RAD  ;;; ALL'S WELL

if (X_RAD GT Y_RAD) then begin
    right_mag = grid_image(SOL_CEN_X + X_RAD, SOL_CEN_Y)
    bottom_mag = grid_image(SOL_CEN_X, SOL_CEN_Y - Y_RAD)
    SOL_RAD = (X_RAD + Y_RAD)/2
endif else begin
    bottom_mag = grid_image(SOL_CEN_X, SOL_CEN_Y - Y_RAD)
    right_mag = grid_image(SOL_CEN_X + X_RAD, SOL_CEN_Y)
    SOL_RAD = (Y_RAD + X_RAD)/2
endelse
left_mag = grid_image(SOL_CEN_X-X_RAD,SOL_CEN_Y)
top_mag = grid_image(SOL_CEN_X,SOL_CEN_Y+Y_RAD)



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Now that the center has been found, along with solar dimensions, it is time
;; to overlay the grid.
;; First,  a new "window" dimension must be specified for the grid so that it
;; overlays only the solar image and NOT the entire Window.
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

_x_not = SOL_CEN_X - SOL_RAD - 8 ;; 8 is subtracted to account for grid not reaching the edge
				 ;; of the window that encloses the solar image.
_y_not = SOL_CEN_Y - SOL_RAD - 8

_x_one = SOL_CEN_X + SOL_RAD + 8

_y_one = SOL_CENY + SOL_RAD + 8

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; These values for x0,y0,x1, and y1 must be converted from pixel locations (device
;; dimensions) into normalized coordinates( 0 to 1 ). 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

_x_not = x_not / 1534. & _y_not = y_not / 1029.
_x_one = x_one / 1534. & _y_one = y_one / 1029.

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Now in Normalized coordinates it's time to draw the grid.
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

set_map, /noerase, /noborder, /ortho, pos=[_x_not, _y_not, _x_one, _y_one]
map_grid, color = 0, latdel=10, londel=10, Gridstyle = 4


end   ;; Done with the grid routine...
