;This procedure is intended for use as part of the PMIAS system.  This system
;has been developed by the HAO dPMon project to facilitate the initial
;quality assurance procedures required for new dPmon data.  Please make
;no changes to any of the files in this directory without first contacting
;dPMon personnel.
;
;   Questions regarding PMIAS should be directed to:
;
;			Ray Wrigley     FL2 3084  x1588
;			Alice Lecinski  FL2 3037  x1523
;
;   The purpose of this module is to sort through the directory where
;   the current day's data is stored and sort the filenames into arrays
;   of strings, each of  which contain all the filenames of one type of
;   image (e.g. sky, limb, etc.).   Also, this is a convenient time to
;   set up string arrays and such for the log file entry process.
;
pro pmias_filesort
@pmias_common

spawn, '(cd /local/dpraw/' + dataday + '; /bin/ls -1)', files

files = files(1:n_elements(files) - 1)	;Strip first element- don't need it.

lm_f_subs = where(strmid(files, 13, 3) eq '.l.')
sk_f_subs = where(strmid(files, 13, 3) eq '.s.')
ds_f_subs = where(strmid(files, 13, 3) eq '.d.')
ff_f_subs = where(strmid(files, 13, 3) eq '.f.')
lmd_f_subs = where(strmid(files, 13, 3) eq '.ld')
skd_f_subs =  where(strmid(files, 13, 3) eq '.sd')
dsd_f_subs =  where(strmid(files, 13, 3) eq '.dd')
ffd_f_subs =  where(strmid(files, 13, 3) eq '.fd')

;If there are files of a certain type, then set up a string array of their
;names, and set up the logfile housekeeping stuff.

if lm_f_subs(0) ne -1 then begin
   limb_fnms = files(lm_f_subs)
   nm = n_elements(limb_fnms)
   lm_comments = strarr(nm)
   lm_done = intarr(nm)
   lm_qual = strarr(nm)
endif else begin
   lm_done = [1]
   limb_fnms = 'n'
   log_done(0) = 1
   lm_qual = ' '
   lm_comments = ' '
endelse

if ds_f_subs(0) ne -1 then begin
   disk_fnms = files(ds_f_subs)
   nm = n_elements(disk_fnms)
   ds_comments = strarr(nm)
   ds_done = intarr(nm)
   ds_qual = strarr(nm)
endif else begin
   ds_done = [1]
   disk_fnms = 'n'
   log_done(1) = 1
   ds_qual = ' '
   ds_comments = ' '
endelse

if sk_f_subs(0) ne -1 then begin
   sky_fnms = files(sk_f_subs)
   nm = n_elements(sky_fnms)
   sk_comments = strarr(nm)
   sk_done = intarr(nm)
   sk_qual = strarr(nm)
endif else begin
   sk_done = [1]
   sky_fnms = 'n'
   log_done(2) = 1
   sk_qual = ' '
   sk_comments = ' '
endelse

if ff_f_subs(0) ne -1 then begin
   flat_fnms = files(ff_f_subs)
   nm = n_elements(flat_fnms)
   ff_comments = strarr(nm)
   ff_done = intarr(nm)
   ff_qual = strarr(nm)
endif else begin
   ff_done = [1]
   flat_fnms = 'n'
   log_done(3) = 1
   ff_qual = ' '
   ff_comments = ' '
endelse

if lmd_f_subs(0) ne -1 then begin
   limbd_fnms = files(lmd_f_subs)
   nm = n_elements(limbd_fnms)
   lmd_comments = strarr(nm)
   lmd_done = intarr(nm)
   lmd_qual = strarr(nm)
endif else begin
   lmd_done = [1]
   limbd_fnms = 'n'
   log_done(4) = 1
   lmd_qual = ' '
   lmd_comments = ' '
endelse

if dsd_f_subs(0) ne -1 then begin
   diskd_fnms = files(dsd_f_subs)
   nm = n_elements(diskd_fnms)
   dsd_comments = strarr(nm)
   dsd_done = intarr(nm)
   dsd_qual = strarr(nm)
endif else begin
   dsd_done = [1]
   diskd_fnms = 'n'
   log_done(5) = 1
   dsd_qual = ' '
   dsd_comments = ' '
endelse

if skd_f_subs(0) ne -1 then begin
   skyd_fnms = files(skd_f_subs)
   nm = n_elements(skyd_fnms)
   skd_comments = strarr(nm)
   skd_done = intarr(nm)
   skd_qual = strarr(nm)
endif else begin
   skd_done = [1]
   skyd_fnms = 'n'
   log_done(6) = 1
   skd_qual = ' '
   skd_comments = ' '
endelse

if ffd_f_subs(0) ne -1 then begin
   flatd_fnms = files(ffd_f_subs)
   nm = n_elements(flatd_fnms)
   ffd_comments = strarr(nm)
   ffd_done = intarr(nm)
   ffd_qual = strarr(nm)
endif else begin
   ffd_done = [1]
   flatd_fnms = 'n'
   log_done(7) = 1
   ffd_qual = ' '
   ffd_comments = ' '
endelse

;Finally, and this sucks, there's really no better way to get the start and
;stop time for the log files than to get it from the filenames.
files_trim = files(where(strmid(files, 0, 1) eq '9'))
tm_str = strmid(files_trim, 7, 6)
hrs_str = fix(strmid(tm_str, 0, 2))
min_str = fix(strmid(tm_str, 2, 2))
rollover = where(hrs_str lt 10)		;A few lines to add 24 hrs to where
if rollover(0) ne -1 then begin		;the clock goes past midnight.
   hrs_str(rollover) = hrs_str(rollover + 24)
endif

tm_vals = float(hrs_str + min_str/60.)
max_ix = (where(tm_vals eq max(tm_vals)))(0)
min_ix = (where(tm_vals eq min(tm_vals)))(0)

stop_time = strmid(tm_str(max_ix), 0, 2)+':'+strmid(tm_str(max_ix), 2, 2)
start_time =  strmid(tm_str(min_ix), 0, 2)+':'+strmid(tm_str(min_ix), 2, 2)

return
end


