;This procedure is intended for use as part of the PMIAS system.  This system
;has been developed by the HAO dPMon project to facilitate the initial
;quality assurance procedures required for new dPMon data.  Please make
;no changes to any of the files in this directory without first contacting
;dPMon personnel.
;
;   Questions regarding PMIAS should be directed to:
;
;			Ray Wrigley     FL2 3084  x1588
;			Alice Lecinski  FL2 3037  x1523
;
;   The purpose of this module is to respond to the user's demand as to
;   which image to view next in the currently loaded image type.
;
pro pmias_imchange, val
@pmias_common

;Erase title screen if this is the first time through.
if title eq 1 then begin
   plot, [0, 0], [0, 0]
   ;pmias_colorscale, 'B/W LG-20'
   title = 0
endif

;Erase enlarged image if one was present in plot window.
if enlarged eq 1 then begin
   plot, [0, 0], [0, 0] 
   widget_control, col1eb, sensitive = 0
   enlarged = 0
endif

;Re-enable logfile controls if continuing after recalling image from
;another image type (see PMIAS_RECALL.PRO).
if wrongtyp eq 1 then begin
   wrongtyp = 0
   widget_control, col2b, sensitive = 1
   widget_control, usr_out1, set_value = $
   'Select quality and then enter comment for each image, limit 45 chars.'
endif

case val of 
   'init' : cntr = 0		;Initialize counter on first image of set.
   'PREV' : begin
	       cntr = cntr - 1
	       if cntr lt 0 then cntr = n_images - 1
	    end
   'NEXT' : cntr = (cntr + 1)mod(n_images)
   'FFWD' : cntr = (cntr + 10)mod(n_images)
   'REWD' : begin
	       cntr = cntr - 10
	       if cntr lt 0 then begin
		   repeat cntr = n_images + cntr until cntr ge 0
	       endif
	    end
   'NXLOG' : cntr = next_intyp
   'REDRAW' : cntr = cntr
   'OVERRIDE' : begin
		   diff = abs(slide_set - tmarr)
		   tmp_cntr = where(diff eq min(diff))
		   cntr = tmp_cntr(0)
		end
 'ANIMATE':for w=0,n_images-1 do device,copy=[0,0,511,342,258,343,pwin_inds(w)]
endcase

;Copy from pixmap to realized draw widget.
device, copy = [0, 0, 511, 342, 258, 343, pwin_inds(cntr)]

;Display any log entries already pending for chosen image.
case cur_typ of
   'LIMB' : begin
	       widget_control, usr_out2, set_value = lm_qual(cntr)
	       widget_control, usr_in1, set_value = lm_comments(cntr)
	    end
   'DISK' : begin
	       widget_control, usr_out2, set_value = ds_qual(cntr)
	       widget_control, usr_in1, set_value = ds_comments(cntr)
	    end
   'SKY' : begin
	      widget_control, usr_out2, set_value = sk_qual(cntr)
	      widget_control, usr_in1, set_value = sk_comments(cntr)
	   end
   'DIFFUSER' : begin
		   widget_control, usr_out2, set_value = ff_qual(cntr)
		   widget_control, usr_in1, set_value = ff_comments(cntr)
		end
   'LIMB DARK' : begin
		    widget_control, usr_out2, set_value = lmd_qual(cntr)
		    widget_control, usr_in1, set_value = lmd_comments(cntr)
		 end
   'DISK DARK' : begin
		    widget_control, usr_out2, set_value = dsd_qual(cntr)
		    widget_control, usr_in1, set_value = dsd_comments(cntr)
		 end
   'SKY DARK' : begin
		   widget_control, usr_out2, set_value = skd_qual(cntr)
		   widget_control, usr_in1, set_value = skd_comments(cntr)
		end
   'DIFF DARK' : begin
		    widget_control, usr_out2, set_value = ffd_qual(cntr)
		    widget_control, usr_in1, set_value = ffd_comments(cntr)
		 end
endcase

;Section to output to user and header information widgets.
widget_control, curim, set_value = string(cntr)
widget_control, imtyp, set_value = cur_typ

widget_control, obsdat, set_value = info_set(cntr, 0)
widget_control, obstim, set_value = info_set(cntr, 1)
widget_control, nexpos, set_value = info_set(cntr, 2)
widget_control, solrad, set_value = info_set(cntr, 3)
widget_control, aptwhl, set_value = info_set(cntr, 4)
widget_control, daysfil, set_value = info_set(cntr, 5)
widget_control, filtwhl, set_value = info_set(cntr, 6)
widget_control, occwhl, set_value = info_set(cntr, 7)
widget_control, hotpix, set_value = string(hot_pix(cntr))
widget_control, coldpix, set_value = string(cold_pix(cntr))

;Set time slider to correct position.
nm = n_images - 1
mint = float(strmid(fnms(0), 7, 2)) + float(strmid(fnms(0), 9, 2))/60.
maxt = float(strmid(fnms(nm), 7, 2)) + float(strmid(fnms(nm), 9, 2))/60.
if maxt lt mint then maxt = maxt + 24.
nowt = float(strmid(fnms(cntr), 7, 2)) + float(strmid(fnms(cntr),9,2))/60.
if nowt lt mint then nowt = nowt + 24.
tim_val = fix(1000 * (nowt - mint) / (maxt - mint))
widget_control, time_slide, set_value = tim_val

return
end

