;This procedure is intended for use as part of the PMIAS system.  This system
;has been developed by the HAO dPMon project to facilitate the initial
;quality assurance procedures required for new dPMon data.  Please make
;no changes to any of the files in this directory without first contacting
;dPMon personnel.
;
;   Questions regarding PMIAS should be directed to:
;
;			Ray Wrigley     FL2 3084  x1588
;			Alice Lecinski  FL2 3037  x1523
;
;   This module displays the next image of the type requested, loading
;   images of that type to RAM in reduced form - 511X342 rebinned.
;
pro pmias_load_images, val
@pmias_common

datain = 0			;Flag for use later.

;Clear out windows if already in use.
if pwin_inds(0) ne 0 then for v = 0, n_images-1 do wdelete, pwin_inds(v)

;Clear out header info widgets during load.
widget_control, obsdat, set_value =  ' '
widget_control, obstim, set_value = ' '
widget_control, nexpos, set_value = ' '
widget_control, solrad, set_value = ' '
widget_control, aptwhl, set_value = ' '
widget_control, daysfil, set_value = ' '
widget_control, filtwhl, set_value = ' '
widget_control, occwhl, set_value = ' '
widget_control, hotpix, set_value = ' '
widget_control, coldpix, set_value = ' '

if(not n_elements(im_array)) then  im_array=intarr(xsz,ysz)

case val of			;Get number of images of selected type.
   'LIMB' : begin
	       n_images = n_elements(limb_fnms)
	       fnms = limb_fnms
	    end
   'DISK' : begin
	       n_images = n_elements(disk_fnms)
	       fnms = disk_fnms
	    end
   'SKY' : begin
	      n_images = n_elements(sky_fnms)
	      fnms = sky_fnms
	    end
   'DIFFUSER' : begin
		   n_images = n_elements(flat_fnms)
		   fnms = flat_fnms
		end
   'LIMB DARK' : begin
		    n_images = n_elements(limbd_fnms)
		    fnms = limbd_fnms
		 end
   'DISK DARK' : begin
		    n_images = n_elements(diskd_fnms)
		    fnms = diskd_fnms
		 end
   'SKY DARK' : begin
		   n_images = n_elements(skyd_fnms)
		   fnms = skyd_fnms
		end
   'DIFF DARK' : begin
		    n_images = n_elements(flatd_fnms)
		    fnms = flatd_fnms
		 end
endcase

if strtrim(fnms(0), 2) eq 'n' then goto, NOFILE

hdrs = ' '		;Nucleus for fits header storage.
hot_pix = intarr(n_images)	;Array to save maximum pixels in images.
cold_pix = intarr(n_images)	;Array to save minimum pixels in images.

widget_control, totim, set_value = string(n_images)	;Inform user.
pwin_inds = intarr(n_images)	;Vector to hold pixwin indexes.

get_lun, lun

for t = 0, n_images - 1 do begin
   widget_control, usr_out1, set_value = 'Loading image ' + string(t)
   im_tmp = readfits('/local/dpraw/' + dataday + '/' + fnms(t), fitshdr)
   hdrs = [hdrs, fitshdr]	;Add to string holding all header info.
   hot_pix(t) = max(im_tmp)	;Save max and min pixels from each image.
   cold_pix(t) = min(im_tmp)

;	In the rebinning below, the top ans bottom rows and the right column
;	of im_tmp is dropped in order to make the array dimensions even
;	multiples of three.  This is necessary for the rebin routine,
;	which requires the result array to have dimensions which are
;	factors or multiples of the original array.

   case val of;{
      'LIMB' : begin
		im_array=rebin(im_tmp(0:xsz*scl-1,0:ysz*scl-1),xsz,ysz)
               end
      'DISK' : begin
		im_array=rebin(im_tmp(0:xsz*scl-1,0:ysz*scl-1),xsz,ysz)
               end
      else:     im_array=rebin(im_tmp(0:xsz*scl-1,0:ysz*scl-1),xsz,ysz)
   endcase    ;}
   window, /free, xsize = xsz, ysize = ysz, /pixmap	;Create pixmap.
   pwin_inds(t) = !d.window			;Get pixmap index.
   wset, pwin_inds(t)				;Direct output to pixmap.

   case datascale of		;Write image to pixmap according to scaling.
      0 : begin
	     n_exp = fix(strmid(fitshdr(32), 10, 21))
	     im_array = im_array / (4. * n_exp)
	     mni=min(im_array(10:xsz-10,10:ysz-10),max=mxi )
	     tv, bytscl(im_array,min=mni,max=mxi)
	  end
      1 : tv, bytscl(im_array, min = 0, max = 800)
   endcase

   wset, plot_index1	;Set output to draw widget to quickly display image.
   device, copy = [0, 0, xsz, ysz, wxp, wyp, pwin_inds(t)]
   widget_control, curim, set_value = string(t)
endfor

datain = 1		;Flag to indicate data was loaded, used below.

free_lun, lun

;Set up time arrays for eventual reading of the time slider.
hrarr = float(strmid(fnms, 7, 2))
minarr = float(strmid(fnms, 9, 2))
tmarr = (hrarr + minarr/60.) - min(hrarr + minarr/60.)
tmarr = tmarr * (1000./max(tmarr))

wset, plot_index1		;Set output to draw widget.

NOFILE:
if datain ne 1 then begin
   widget_control, totim, set_value = ' '
   widget_control, usr_out1, set_value = 'No files of that type today.'
endif

return
end
